@@ -1,12 +1,12 @@
 skip_conditionally <- function() {
-  if (!nzchar(Sys.which("julia"))) {
-    testthat::skip("No Julia installation detected.")
-  }
   if (!JuliaConnectoR::juliaSetupOk()) {
-    testthat::skip("Julia installed but not discoverable via {JuliaConnectoR}.")
+    testthat::skip("No Julia installation detected via {JuliaConnectoR}.")
   }
   if (!julia_version_compatible()) {
     testthat::skip("Julia version >=1.8 required.")
   }
+  if (!check_julia_ok()) {
+    testthat::skip("`check_julia_ok()` is FALSE.")
+  }
   invisible()
 }
